Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6)

Unified Diff: tests/compiler/dart2js_native/subclassing_constructor_1_test.dart

Issue 28173002: Code review changes for ngeoffray's comments on r28278 (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/html/dartium/html_dartium.dart ('k') | tools/dom/src/dart2js_CustomElementSupport.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/compiler/dart2js_native/subclassing_constructor_1_test.dart
diff --git a/tests/compiler/dart2js_native/subclassing_constructor_1_test.dart b/tests/compiler/dart2js_native/subclassing_constructor_1_test.dart
index 333a9f2f5e02a6e0b4f3ef436460bb7ec682584e..36fed2ec49fe2ddfc5070c080b289021ff8e2624 100644
--- a/tests/compiler/dart2js_native/subclassing_constructor_1_test.dart
+++ b/tests/compiler/dart2js_native/subclassing_constructor_1_test.dart
@@ -6,7 +6,7 @@ import "package:expect/expect.dart";
import 'dart:_foreign_helper' show JS;
import 'dart:_js_helper' show Creates, setNativeSubclassDispatchRecord;
import 'dart:_interceptors' show
- findInterceptorForType, findConstructorForWebComponentType;
+ findInterceptorForType, findConstructorForNativeSubclassType;
// Test that subclasses of native classes can be initialized by calling the
// 'upgrade' constructor.
@@ -69,9 +69,9 @@ getBPrototype = function(){return B.prototype;};
test_one() {
trace = [];
- var constructor = findConstructorForWebComponentType(B, 'one');
+ var constructor = findConstructorForNativeSubclassType(B, 'one');
Expect.isNotNull(constructor);
- Expect.isNull(findConstructorForWebComponentType(B, 'Missing'));
+ Expect.isNull(findConstructorForNativeSubclassType(B, 'Missing'));
var b = makeB();
Expect.isTrue(b is B);
@@ -93,7 +93,7 @@ test_one() {
test_two() {
trace = [];
- var constructor = findConstructorForWebComponentType(B, 'two');
+ var constructor = findConstructorForNativeSubclassType(B, 'two');
Expect.isNotNull(constructor);
var b = makeB();
@@ -117,7 +117,7 @@ test_two() {
test_three() {
trace = [];
- var constructor = findConstructorForWebComponentType(B, 'three');
+ var constructor = findConstructorForNativeSubclassType(B, 'three');
Expect.isNotNull(constructor);
var b = makeB();
@@ -128,7 +128,7 @@ test_three() {
// is as though the web components runtime explicitly passed `null` for all
// parameters.
//
// TODO(sra): The constructor returned by findConstructorForWebComponentType
// should be a function that fills in the default values.
JS('', '#(#)', constructor, b);
Expect.isTrue(b is B);
@@ -128,7 +128,7 @@ test_three() {
// parameters.
//
- // TODO(sra): The constructor returned by findConstructorForWebComponentType
+ // TODO(sra): The constructor returned by findConstructorForNativeSubclassType
// should be a function that fills in the default values.
JS('', '#(#)', constructor, b);
« no previous file with comments | « sdk/lib/html/dartium/html_dartium.dart ('k') | tools/dom/src/dart2js_CustomElementSupport.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698